summaryrefslogtreecommitdiffstats
path: root/apps/user_ldap/lib/ildapwrapper.php
diff options
context:
space:
mode:
Diffstat (limited to 'apps/user_ldap/lib/ildapwrapper.php')
-rw-r--r--apps/user_ldap/lib/ildapwrapper.php116
1 files changed, 58 insertions, 58 deletions
diff --git a/apps/user_ldap/lib/ildapwrapper.php b/apps/user_ldap/lib/ildapwrapper.php
index 017d5549690..146ada125bb 100644
--- a/apps/user_ldap/lib/ildapwrapper.php
+++ b/apps/user_ldap/lib/ildapwrapper.php
@@ -30,9 +30,9 @@ interface ILDAPWrapper {
/**
* @brief Bind to LDAP directory
* @param resource $link LDAP link resource
- * @param $dn an RDN to log in with
- * @param $password the password
- * @return true on success, false otherwise
+ * @param string $dn an RDN to log in with
+ * @param string $password the password
+ * @return bool true on success, false otherwise
*
* with $dn and $password as null a anonymous bind is attempted.
*/
@@ -40,28 +40,28 @@ interface ILDAPWrapper {
/**
* @brief connect to an LDAP server
- * @param $host The host to connect to
- * @param $port The port to connect to
- * @return a link resource on success, otherwise false
+ * @param string $host The host to connect to
+ * @param string $port The port to connect to
+ * @return mixed a link resource on success, otherwise false
*/
public function connect($host, $port);
/**
* @brief Send LDAP pagination control
* @param $link LDAP link resource
* @param $pagesize number of results per page
* @param boolean $isCritical Indicates whether the pagination is critical of not.
* @param $cookie structure sent by LDAP server
* @return true on success, false otherwise
*/
- public function controlPagedResult($link, $pagesize, $isCritical, $cookie);
+ public function controlPagedResult($link, $pageSize, $isCritical, $cookie);
/**
* @brief Retrieve the LDAP pagination cookie
* @param $link LDAP link resource
* @param $result LDAP result resource
- * @param $cookie structure sent by LDAP server
- * @return boolean on success, false otherwise
+ * @param array $cookie structure sent by LDAP server
+ * @return bool true on success, false otherwise
*
* Corresponds to ldap_control_paged_result_response
*/
@@ -69,101 +69,101 @@ interface ILDAPWrapper {
/**
* @brief Count the number of entries in a search
- * @param $link LDAP link resource
- * @param $result LDAP result resource
- * @return mixed, number of results on success, false otherwise
+ * @param resource $link LDAP link resource
+ * @param resource $result LDAP result resource
+ * @return int|false number of results on success, false otherwise
*/
public function countEntries($link, $result);
/**
* @brief Return the LDAP error number of the last LDAP command
- * @param $link LDAP link resource
- * @return error message as string
+ * @param resource $link LDAP link resource
+ * @return string error message as string
*/
public function errno($link);
/**
* @brief Return the LDAP error message of the last LDAP command
- * @param $link LDAP link resource
- * @return error code as integer
+ * @param resource $link LDAP link resource
+ * @return int error code as integer
*/
public function error($link);
/**
* @brief Return first result id
- * @param $link LDAP link resource
- * @param $result LDAP result resource
- * @return an LDAP search result resource
+ * @param resource $link LDAP link resource
+ * @param resource $result LDAP result resource
+ * @return Resource an LDAP search result resource
* */
public function firstEntry($link, $result);
/**
* @brief Get attributes from a search result entry
- * @param $link LDAP link resource
- * @param $result LDAP result resource
+ * @param resource $link LDAP link resource
+ * @param resource $result LDAP result resource
* @return array containing the results, false on error
* */
public function getAttributes($link, $result);
/**
* @brief Get the DN of a result entry
- * @param $link LDAP link resource
- * @param $result LDAP result resource
+ * @param resource $link LDAP link resource
+ * @param resource $result LDAP result resource
* @return string containing the DN, false on error
*/
public function getDN($link, $result);
/**
* @brief Get all result entries
- * @param $link LDAP link resource
- * @param $result LDAP result resource
+ * @param resource $link LDAP link resource
+ * @param resource $result LDAP result resource
* @return array containing the results, false on error
*/
public function getEntries($link, $result);
/**
* @brief Return next result id
- * @param $link LDAP link resource
+ * @param resource $link LDAP link resource
* @param resource $result LDAP entry result resource
- * @return an LDAP search result resource
+ * @return resource an LDAP search result resource
* */
public function nextEntry($link, $result);
/**
* @brief Read an entry
- * @param $link LDAP link resource
- * @param $baseDN The DN of the entry to read from
- * @param $filter An LDAP filter
- * @param $attr array of the attributes to read
- * @return an LDAP search result resource
+ * @param resource $link LDAP link resource
+ * @param array $baseDN The DN of the entry to read from
+ * @param string $filter An LDAP filter
+ * @param array $attr array of the attributes to read
+ * @return resource an LDAP search result resource
*/
public function read($link, $baseDN, $filter, $attr);
/**
* @brief Search LDAP tree
* @param $link LDAP link resource
* @param $baseDN The DN of the entry to read from
* @param $filter An LDAP filter
* @param $attr array of the attributes to read
* @param $attrsonly optional, 1 if only attribute types shall be returned
* @param $limit optional, limits the result entries
* @return an LDAP search result resource, false on error
*/
- public function search($link, $baseDN, $filter, $attr, $attrsonly = 0, $limit = 0);
+ public function search($link, $baseDN, $filter, $attr, $attrsOnly = 0, $limit = 0);
/**
* @brief Sets the value of the specified option to be $value
- * @param $link LDAP link resource
- * @param $option a defined LDAP Server option
- * @param integer $value the new value for the option
- * @return true on success, false otherwise
+ * @param resource $link LDAP link resource
+ * @param string $option a defined LDAP Server option
+ * @param int $value the new value for the option
+ * @return bool true on success, false otherwise
*/
public function setOption($link, $option, $value);
/**
* @brief establish Start TLS
- * @param $link LDAP link resource
- * @return true on success, false otherwise
+ * @param resource|$link LDAP link resource
+ * @return bool true on success, false otherwise
*/
public function startTls($link);
@@ -171,35 +171,35 @@ interface ILDAPWrapper {
* @brief Sort the result of a LDAP search
* @param $link LDAP link resource
* @param $result LDAP result resource
- * @param $sortfilter attribute to use a key in sort
+ * @param string $sortFilter attribute to use a key in sort
*/
- public function sort($link, $result, $sortfilter);
+ public function sort($link, $result, $sortFilter);
/**
* @brief Unbind from LDAP directory
* @param resource $link LDAP link resource
- * @return true on success, false otherwise
+ * @return bool true on success, false otherwise
*/
public function unbind($link);
- //additional required methods in owncloud
+ //additional required methods in ownCloud
/**
* @brief Checks whether the server supports LDAP
- * @return boolean if it the case, false otherwise
+ * @return bool true if it the case, false otherwise
* */
public function areLDAPFunctionsAvailable();
/**
* @brief Checks whether PHP supports LDAP Paged Results
- * @return boolean if it the case, false otherwise
+ * @return bool true if it the case, false otherwise
* */
public function hasPagedResultSupport();
/**
* @brief Checks whether the submitted parameter is a resource
- * @param $resource the resource variable to check
- * @return boolean if it is a resource, false otherwise
+ * @param resource $resource the resource variable to check
+ * @return bool true if it is a resource, false otherwise
*/
public function isResource($resource);
@@ -40,28 +40,28 @@ interface ILDAPWrapper {
/**
* @brief Send LDAP pagination control
- * @param $link LDAP link resource
- * @param $pagesize number of results per page
- * @param boolean $isCritical Indicates whether the pagination is critical of not.
- * @param $cookie structure sent by LDAP server
+ * @param resource $link LDAP link resource
+ * @param int $pageSize number of results per page
+ * @param bool $isCritical Indicates whether the pagination is critical of not.
+ * @param array $cookie structure sent by LDAP server
* @return true on success, false otherwise
*/
@@ -69,101 +69,101 @@ interface ILDAPWrapper {
/**
* @brief Search LDAP tree
- * @param $link LDAP link resource
- * @param $baseDN The DN of the entry to read from
- * @param $filter An LDAP filter
- * @param $attr array of the attributes to read
- * @param $attrsonly optional, 1 if only attribute types shall be returned
- * @param $limit optional, limits the result entries
- * @return an LDAP search result resource, false on error
+ * @param resource $link LDAP link resource
+ * @param string $baseDN The DN of the entry to read from
+ * @param string $filter An LDAP filter
+ * @param array $attr array of the attributes to read
+ * @param int $attrsOnly optional, 1 if only attribute types shall be returned
+ * @param int $limit optional, limits the result entries
+ * @return resource|false an LDAP search result resource, false on error
*/